#!/bin/sh

. ./build-env.sh

lxmmmkb=`echo ${lxdebkb} | cut -d '.' -f 1-2`

export ARCH=arm64
if [ "X${BSP_ARCH}" = "Xarmhf" ]; then
  export ARCH=arm
  export CROSS_COMPILE=arm-linux-gnueabihf-

elif [ "X${BSP_ARCH}" = "Xarm64" ]; then
  export ARCH=arm64
  export CROSS_COMPILE=aarch64-linux-gnu-

elif [ "X${BSP_ARCH}" = "Xriscv64" ]; then
  export ARCH=riscv
  export CROSS_COMPILE=riscv64-linux-gnu-

  t=`pwd`/prebuilt/gcc/linux-x86/riscv/toolchain-thead-glibc/riscv64-glibc-gcc-thead_20200702/bin/riscv64-unknown-linux-gnu-
  u=`pwd`/riscv64-glibc-gcc-thead_20200903/9.3.1/bin/riscv64-unknown-linux-gnu-
  if [ -e ${u}gcc ]; then
    export CROSS_COMPILE=$u
  elif [ -e ${t}gcc ]; then
    export CROSS_COMPILE=$t
  fi

elif [ "X${BSP_ARCH}" = "Xamd64" ]; then
  export ARCH=x86
  export CROSS_COMPILE=x86_64-linux-gnu-

elif [ "X${BSP_ARCH}" = "Xi686" ]; then
  export ARCH=x86
  export CROSS_COMPILE=i686-linux-gnu-

elif [ "X${BSP_ARCH}" = "Xpowerpc" ]; then
  export ARCH=powerpc
  export CROSS_COMPILE=powerpc-linux-gnu-
fi

export LOCALVERSION="+${BSP_GROUP}"

defcfg=${BSP_CONFIG}_defconfig
ldcfg=${lxmmmkb}-${BSP_GROUP}.config
lxcfg=.config


change_lxcfg() {
  c=${lxcfg}
  if [ "x$2" = "x-" ]; then
    sed -i 's|'"$1"'||g' $c
  elif [ "x$2" = "xn" ]; then
    if grep -q -E $1'=.*' $c ; then
      sed -i 's|'$1'=.*|# '$1' is not set|g' $c
    elif ! grep -q '# '$1' is not set' $c ; then
      echo '# '$1' is not set' >> $c
    fi
  else
    if grep -q $1'='$2 $c ; then
      true
    elif grep -q -E $1'=.*' $c ; then
      sed -i 's|'$1'=.*|'$1'='$2'|g' $c
    elif grep -q '# '$1' is not set' $c ; then
      sed -i 's|# '$1' is not set|'$1'='$2'|g' $c
    else
      echo $1'='$2 >> $c
    fi
  fi
}


echo "Using ${CROSS_COMPILE}"

cd linux

famcfg=meson64
if [ "${BSP_DTS:0:4}" = "rk33" ]; then
  famcfg=rk33
fi

famsrc=${famcfg}
#famcfg=sbc
tmpcfg=${BSP_CONFIG}
tmpcfg=`echo ${tmpcfg} | sed s/'_linux$'/''/g`

if [ ! -e ../patches/${tmpcfg}-${famcfg}_defconfig-template ]; then
  tmpcfg=`echo ${BSP_MODEL} | sed s/'-rk33..$'/''/g`-${tmpcfg}
fi

if [ ! -e ../patches/${tmpcfg}-${famcfg}_defconfig-template ]; then
  tmpcfg=`echo ${BSP_MODEL} | sed s/'-rk33..$'/''/g`
fi

if [ -e ../patches/${tmpcfg}-${famcfg}_defconfig-template ]; then
  defcfg=${tmpcfg}-${famcfg}_defconfig
  lxcfg=arch/${ARCH}/configs/${defcfg}
  echo "Using ${defcfg}-template"
  #echo "cp -p ../patches/${famcfg}_defconfig ${lxcfg}"
  cp -p ../patches/${famsrc}_defconfig ${lxcfg}
  #echo "cat ../patches/${defcfg}-template >> ${lxcfg}"
  #cat ../patches/${defcfg}-template >> ${lxcfg}

  cat ../patches/${defcfg}-template | while read c ; do
    n=`echo $c | cut -d '=' -f 1`
    v=`echo $c | cut -d '=' -f 2-`
    if ! echo $c | grep -q '=' ; then
      n=`echo $c | cut -d ' ' -f 2`
      v=n
    fi
    change_lxcfg $n $v
  done
else
  echo "Using ${defcfg}"
  if [ -e ../patches-optional/${defcfg} -a ! -e arch/${ARCH}/configs/${defcfg} ]; then
    cp -p ../patches-optional/${defcfg} arch/${ARCH}/configs/
  fi
fi

make LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} defconfig

if [ ! -e config-0 ]; then
  cp -p .config config-0
fi

if [ -e arch/${ARCH}/configs/${defcfg} ]; then
  echo "Using ${defcfg}"

  make LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} ${defcfg}

  cp -p .config $ldcfg
fi

lxcfg=.config
cp -p $ldcfg $lxcfg

sed -i 's|^CONFIG_LOCALVERSION_AUTO=.*|# CONFIG_LOCALVERSION_AUTO is not set|g' $lxcfg
sed -i 's|^CONFIG_DEFAULT_HOSTNAME=.*|CONFIG_DEFAULT_HOSTNAME="(none)"|g' $lxcfg

sed -i 's|^CONFIG_DEBUG_INFO=y|# CONFIG_DEBUG_INFO is not set|g' $lxcfg

if false ; then
sed -i 's|^CONFIG_STMMAC_ETH=m|CONFIG_STMMAC_ETH=y|g' $lxcfg
sed -i 's|^CONFIG_STMMAC_PLATFORM=m|CONFIG_STMMAC_PLATFORM=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_GENERIC=m|CONFIG_DWMAC_GENERIC=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_IPQ806X=m|CONFIG_DWMAC_IPQ806X=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_MESON=m|CONFIG_DWMAC_MESON=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_ROCKCHIP=m|CONFIG_DWMAC_ROCKCHIP=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_SUNXI=m|CONFIG_DWMAC_SUNXI=y|g' $lxcfg
fi

make LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} oldconfig

cd ..

echo OK
